@@ -3,8 +3,8 @@
 
 # Robust Scale Estimator found in Rousseeuw & Verboven (2002)
 
-robScale <- function(x, loc = NULL, implbound = 1e-4, na.rm = FALSE, maxit = 80,
-                   tol = sqrt(.Machine$double.eps)) {
+robScale <- function(x, loc = NULL, implbound = 1e-4, na.rm = FALSE,
+                     maxit = 80L, tol = sqrt(.Machine$double.eps)) {
   if (na.rm) {
     x <- x[!is.na(x)]
   } else {
@@ -16,11 +16,11 @@ robScale <- function(x, loc = NULL, implbound = 1e-4, na.rm = FALSE, maxit = 80,
     x <- x - loc
     s <- 1.4826 * median(abs(x))
     t <- 0
-    minobs <- 3
+    minobs <- 3L
   } else {
     s <- mad(x)
     t <- median(x)
-    minobs <- 4
+    minobs <- 4L
   }
   if (length(x) < minobs) {
     if (mad(x) <= implbound) {
@@ -30,9 +30,9 @@ robScale <- function(x, loc = NULL, implbound = 1e-4, na.rm = FALSE, maxit = 80,
     }
   } else {
     converged <- FALSE
-    k <- 0
-    while (!converged & k < maxit) {
-      k <- k + 1
+    k <- 0L
+    while (!converged && k < maxit) {
+      k <- k + 1L
       v <- sqrt(2 * mean((2 * plogis(((x - t) / s) / 0.3739) - 1) ^ 2))
       converged <- abs(v - 1) <= tol
       s <- s * v
